==> patch-3.8.5-ONex-OMS-pro-source-PHP5.6.tar.gz: ShopexErp/app/wms/lib/event/trigger/logistics/data/electron/common.php <==
<?php
class wms_event_trigger_logistics_data_electron_common {
    public $channel;
    protected $directRet = array();
    protected $needRequestId = array();
    protected $needRequestDeliveryId = array();
    protected $needGetWBExtend = false;

    public function setChannel($channel) {
        $this->channel = $channel;
        return $this;
    }

    
    protected function getDirectSdf($arrDelivery, $arrBill, $shop) {
        return false;
    }

    public function directDealParam($arrDeliveryId, $arrBillId) {
        $this->directRet = array();
        $this->needRequestId = array();
        $this->needRequestDeliveryId = array();
        if(empty($arrBillId)) {
            $arrDelivery = $this->preDealDelivery($arrDeliveryId);
        } else {
            $arrDelivery = app::get('wms')->model('delivery')->getList('*', array('delivery_id'=>$arrDeliveryId));
            $arrBill = $this->preDealBillDelivery($arrBillId, $arrDelivery[0]);
        }
        if(empty($arrDelivery) || (isset($arrBill) && empty($arrBill))) {
            return array(
                'succ' => $this->directRet['succ'],
                'fail' => $this->directRet['fail']
            );
        }
        $shop = app::get('logisticsmanager')->model('channel_extend')->dump(array('channel_id'=>$this->channel['channel_id']),'shop_name,province,city,area,address_detail,seller_id,default_sender,mobile,tel,zip');
        $sdf = $this->getDirectSdf($arrDelivery, $arrBill, $shop);
        return array(
            'succ' => $this->directRet['succ'],
            'fail' => $this->directRet['fail'],
            'sdf' =>  $sdf,
            'need_request_id' => $this->needRequestId
        );
    }

    public function preDealDelivery($arrDeliveryId) {

        $arrDelivery = app::get('wms')->model('delivery')->getList('*', array('delivery_id'=>$arrDeliveryId));
        $billObj = app::get('wms')->model('delivery_bill');
        $objWaybill = app::get('logisticsmanager')->model('waybill');
        $needRequest = $hasDelivery = array();
        foreach($arrDelivery as $delivery) {
            $arrBill = $billObj->dump(array('delivery_id'=>$delivery['delivery_id'],'type'=>'1','status'=>'0'),'logi_no');
            $logi_no = $arrBill['logi_no'];
            $hasDelivery[] = $delivery['delivery_id'];
            $filter = array('channel_id' => $this->channel['channel_id'], 'waybill_number' => $logi_no);
            if(!$this->checkLogisticsChannel($delivery['logi_id'])) {
                $this->directRet['fail'][] = array(
                    'delivery_id' => $delivery['delivery_id'],
                    'delivery_bn' => $delivery['delivery_bn'],
                    'msg' => '该发货单已经切换物流公司了'
                );
                continue;
            }
            if (!empty($logi_no) && $objWaybill->dump($filter)) {
                $this->directRet['succ'][] = array(
                    'logi_no' => $logi_no,
                    'delivery_id' => $delivery['delivery_id'],
                    'delivery_bn' => $delivery['delivery_bn']
                );
            } else {
                $needRequest[] = $delivery;
                $this->needRequestDeliveryId[] = $delivery['delivery_id'];
            }
        }
        $noDelivery = array_diff($arrDeliveryId, $hasDelivery);
        if($noDelivery) {
            foreach($noDelivery as $val) {
                $this->directRet['fail'][] = array(
                    'delivery_id' => $val,
                    'msg' => '没有该发货单'
                );
            }
        }
        return $needRequest;
    }

    public function preDealBillDelivery($arrBillId, $delivery) {
        if(!$this->checkLogisticsChannel($delivery['logi_id'])) {
            foreach($arrBillId as $billId) {
                $this->directRet['fail'][] = array(
                    'b_id' => $billId,
                    'delivery_bn' => $delivery['delivery_bn'],
                    'msg' => '物流公司已经切换，不能补打'
                );
            }
            return array();
        }
        $arrBill = app::get('wms')->model('delivery_bill')->getList('*', array('b_id'=>$arrBillId));
        $objWaybill = app::get('logisticsmanager')->model('waybill');
        $needRequest = $hasBill = array();
        foreach($arrBill as $bill) {
            $filter = array('channel_id' => $this->channel['channel_id'], 'waybill_number' => $bill['logi_no']);
            if (!empty($bill['logi_no']) && ($this->channel['channel_type'] == '360buy' || $objWaybill->dump($filter))) {
                $this->directRet['succ'][] = array(
                    'logi_no' => $bill['logi_no'],
                    'b_id' => $bill['b_id'],
                    'delivery_id' => $delivery['delivery_id'],
                    'delivery_bn' => $delivery['delivery_bn']
                );
            } else {
                $needRequest[] = $bill;
            }
            $hasBill[] = $bill['b_id'];
        }
        if(!empty($needRequest)) {
            $this->needRequestDeliveryId[] = $delivery['delivery_id'];
        }
        $noBill = array_diff($arrBillId, $hasBill);
        if($noBill) {
            foreach($noBill as $val) {
                $this->directRet['fail'][] = array(
                    'b_id' => $val,
                    'msg' => '没有该补打单'
                );
            }
        }
        return $needRequest;
    }

    protected function getDeliveryOrder($deliveryId) {
        $db = kernel::database();
        $deliveryIds = $this->getDeliveryIdBywms($deliveryId);
        $where = is_array($deliveryId) ? 'd.delivery_id in (' . (implode(',', $deliveryIds)) . ')' : 'd.delivery_id = "' . $deliveryIds .'"';
        $field = 'o.order_id, o.order_bn, o.total_amount, o.shop_id, o.createway, d.delivery_id';
        $sql = 'select '. $field . ' from sdb_ome_delivery_order as d left join sdb_ome_orders as o using(order_id) where ' . $where;
        $result = $db->select($sql);
        return $result;
    }

    //获取两条订单明细
    protected function getOrderItems($order_id) {
        static $orderItems = array();
        if (!$orderItems[$order_id]) {
            $orderItems[$order_id] = app::get('ome')->model('order_items')->getList('*', array('order_id' => $order_id), 0, 2);
        }
        return $orderItems[$order_id];
    }

    //获取两条发货单明细
    public function getDeliveryItems($delivery_id) {
        static $deliveryItems = array();
        if(!$deliveryItems[$delivery_id]) {
            $deliveryItems[$delivery_id] = app::get('wms')->model('delivery_items')->getList('*', array('delivery_id' => $delivery_id),0,2);
        }
        return $deliveryItems[$delivery_id];
    }

    #设置子单的请求的订单号
    public function setChildRqOrdNo($deliveryBn, $billId){
        $deliveryBn = $deliveryBn."cldordno".$billId;
        return $deliveryBn;
    }

    #检查是否是子单的请求的订单号
    public function checkChildRqOrdNo($deliveryBn, &$main_order_no, &$waybill_cid){
        $pos = strpos($deliveryBn,'cldordno');
        if( $pos !== false){
            $main_order_no = substr($deliveryBn,0,$pos);
            $waybill_cid = substr($deliveryBn,$pos+8);
            return true;
        }else{
            return false;
        }
    }

    #验证物流公司是否是该渠道的
    protected function checkLogisticsChannel($logiId) {
        static $channelLogistics = array();
        if(empty($channelLogistics)) {
            $arrLogistics = app::get('ome')->model('dly_corp')->getList('corp_id', array('channel_id'=>$this->channel['channel_id']));
            foreach($arrLogistics as $val) {
                $channelLogistics[] = $val['corp_id'];
            }
        }
        if(in_array($logiId, $channelLogistics)) {
            return true;
        } else {
            return false;
        }
    }

    public function waybillExtendDealParam($arrDelivery, $arrBill) {
        if(!$this->needGetWBExtend) {
            return false;
        }
        $waybill = array();
        $waybillDelivery = array();
        foreach($arrDelivery as $delivery) {
            if(!empty($delivery['logi_no'])) { //需要有运单号
                $waybill[] = $delivery['logi_no'];
                $waybillDelivery[$delivery['logi_no']] = $delivery;
            }
        }
        if(empty($waybill)) {
            return array('sdf' => false);
        }
        $objExtend = app::get("logisticsmanager")->model("waybill_extend");
        $sql = 'SELECT w.waybill_number, e.id FROM sdb_logisticsmanager_waybill w LEFT JOIN sdb_logisticsmanager_waybill_extend e ON (w.id = e.waybill_id) WHERE w.waybill_number in ("'. implode('","', $waybill) .'") AND w.channel_id = "' . $this->channel['channel_id'] . '"';
        $arrExtend = $objExtend->db->select($sql);
        $needExtendDelivery = array();
        foreach($arrExtend as $val) {
            if(empty($val['id']) && $val['waybill_number']) {//没有大头笔
                $needExtendDelivery[] = $waybillDelivery[$val['waybill_number']];
            }
        }
        if(empty($needExtendDelivery)) {
            $billExtend = true;
            if(!empty($arrBill)) {
                $billExtend = $this->dealBillExtend($arrBill, $arrExtend[0]['id']);
            }
            return array('sdf' => false, 'bill_extend_fail' => !$billExtend);
        }
        $shop = app::get('logisticsmanager')->model('channel_extend')->dump(array('channel_id'=>$this->channel['channel_id']),'province,city,area,address_detail,seller_id,default_sender,mobile,tel,zip');
        $sdf = $this->getWaybillExtendSdf($needExtendDelivery, $shop);
        return array('sdf' => $sdf);
    }

    protected function getWaybillExtendSdf($arrDelivery, $shop) {
        return false;
    }

    protected function dealBillExtend($arrBill, $extendId) {
        $billWaybill = array();
        foreach($arrBill as $bill) {
            $billWaybill[] = $bill['logi_no'];
        }
        $objWaybill = app::get("logisticsmanager")->model("waybill");
        $filter = array(
            'waybill_number' => $billWaybill,
            'channel_id' => $this->channel['channel_id']
        );
        $waybill = $objWaybill->getList('id', $filter);
        $waybillId = array();
        foreach($waybill as $val) {
            $waybillId[$val['id']] = 1;
        }
        $objExtend = app::get("logisticsmanager")->model("waybill_extend");
        $extend = $objExtend->getList('waybill_id', array('waybill_id'=>array_keys($waybillId)));
        foreach($extend as $value) {
            if($waybillId[$value['waybill_id']]) {//有大头笔不更新
                unset($waybillId[$value['waybill_id']]);
            }
        }
        $upWaybillId = array_keys($waybillId);
        if($upWaybillId) {
            $extendData = $objExtend->dump(array('id'=>$extendId));
            unset($extendData['id']);
            $insertData = array();
            foreach($upWaybillId as $wbId) {
                $tmp = $extendData;
                $tmp['waybill_id'] = $wbId;
                $insertData[] = $tmp;
            }
            $sql = ome_func::get_insert_sql($objExtend, $insertData);
            return kernel::database()->exec($sql);
        }
        return true;
    }

    public function getDeliveryIdBywms($deliveryId){
        $db = kernel::database();
        $sql = "SELECT w.outer_delivery_bn FROM sdb_wms_delivery as w WHERE w.delivery_id in (".implode(',', $deliveryId).")";
        $delivery_list = $db->select($sql);
        $delivery_bnList = array();
        foreach ($delivery_list as $delivery){
            $delivery_bnList[] = $delivery['outer_delivery_bn'];
        }

        $deliveryArr = $db->select("SELECT d.delivery_id FROM sdb_ome_delivery as d WHERE d.delivery_bn in(".'\''.implode('\',\'',$delivery).'\''.")");
        $deliveryIds = array();
        foreach ($deliveryArr as $deliverys){
            $deliveryIds[] = $deliverys['delivery_id'];
        }
        return $deliveryIds;
    }

    
}

==> patch-4.1.7-ONex-OMS-pro-source-PHP5.3.tar.gz: ShopexErp/app/wms/lib/event/trigger/logistics/data/electron/common.php <==
<?php
class wms_event_trigger_logistics_data_electron_common {
    public $channel;
    protected $directRet = array();
    protected $needRequestId = array();
    protected $needRequestDeliveryId = array();
    protected $needGetWBExtend = false;

    public function setChannel($channel) {
        $this->channel = $channel;
        return $this;
    }

    public function getDeliverySdf($delivery, $shop) {
        return false;
    }

    public function getDirectSdf($arrDelivery, $arrBill, $shop) {

        $sdf = array();
        $deliveryOrder = $this->getDeliveryOrder($this->needRequestDeliveryId);
        $order_bns = array();
        foreach($deliveryOrder as $val) {
            // 御城河
            if ($val['shop_type'] == 'taobao' && $val['createway'] == 'matrix') $order_bns[]= $val['order_bn'];
        }

        $sdf['order_bns'] = $order_bns;

        return $sdf;
    }

    public function directDealParam($arrDeliveryId, $arrBillId) {
        $this->directRet = array();
        $this->needRequestId = array();
        $this->needRequestDeliveryId = array();
        if(empty($arrBillId)) {
            $arrDelivery = $this->preDealDelivery($arrDeliveryId);
        } else {
            $arrDelivery = app::get('wms')->model('delivery')->getList('*', array('delivery_id'=>$arrDeliveryId));
            $arrBill = $this->preDealBillDelivery($arrBillId, $arrDelivery[0]);
        }
        if(empty($arrDelivery) || (isset($arrBill) && empty($arrBill))) {
            return array(
                'succ' => $this->directRet['succ'],
                'fail' => $this->directRet['fail']
            );
        }
        $arrDelivery = $this->__format_delivery($arrDelivery, $arrBill);
        if(empty($arrDelivery)) {
            return array(
                'succ' => $this->directRet['succ'],
                'fail' => $this->directRet['fail']
            );
        }
        $shop = app::get('logisticsmanager')->model('channel_extend')->dump(array('channel_id'=>$this->channel['channel_id']),'shop_name,province,city,area,address_detail,seller_id,default_sender,mobile,tel,zip');
        $sdf = $this->getDirectSdf($arrDelivery, $arrBill, $shop);
        return array(
            'succ' => $this->directRet['succ'],
            'fail' => $this->directRet['fail'],
            'sdf' =>  $sdf,
            'need_request_id' => $this->needRequestId
        );
    }

    public function preDealDelivery($arrDeliveryId) {

        $arrDelivery = app::get('wms')->model('delivery')->getList('*', array('delivery_id'=>$arrDeliveryId));
        $billObj = app::get('wms')->model('delivery_bill');
        $objWaybill = app::get('logisticsmanager')->model('waybill');
        $needRequest = $hasDelivery = array();
        foreach($arrDelivery as $delivery) {
            $arrBill = $billObj->dump(array('delivery_id'=>$delivery['delivery_id'],'type'=>'1','status'=>'0'),'logi_no');
            $logi_no = $arrBill['logi_no'];
            $hasDelivery[] = $delivery['delivery_id'];
            $filter = array('channel_id' => $this->channel['channel_id'], 'waybill_number' => $logi_no);
            if(!$this->checkLogisticsChannel($delivery['logi_id'])) {
                $this->directRet['fail'][] = array(
                    'delivery_id' => $delivery['delivery_id'],
                    'delivery_bn' => $delivery['delivery_bn'],
                    'msg' => '该发货单已经切换物流公司了'
                );
                continue;
            }
            if (!empty($logi_no) && $objWaybill->dump($filter)) {
                $this->directRet['succ'][] = array(
                    'logi_no' => $logi_no,
                    'delivery_id' => $delivery['delivery_id'],
                    'delivery_bn' => $delivery['delivery_bn']
                );
            } else {
                $needRequest[] = $delivery;
                $this->needRequestDeliveryId[] = $delivery['delivery_id'];
            }
        }
        $noDelivery = array_diff($arrDeliveryId, $hasDelivery);
        if($noDelivery) {
            foreach($noDelivery as $val) {
                $this->directRet['fail'][] = array(
                    'delivery_id' => $val,
                    'msg' => '没有该发货单'
                );
            }
        }
        return $needRequest;
    }

    public function preDealBillDelivery($arrBillId, $delivery) {
        if(!$this->checkLogisticsChannel($delivery['logi_id'])) {
            foreach($arrBillId as $billId) {
                $this->directRet['fail'][] = array(
                    'b_id' => $billId,
                    'delivery_bn' => $delivery['delivery_bn'],
                    'msg' => '物流公司已经切换，不能补打'
                );
            }
            return array();
        }
        $arrBill = app::get('wms')->model('delivery_bill')->getList('*', array('b_id'=>$arrBillId));
        $objWaybill = app::get('logisticsmanager')->model('waybill');
        $needRequest = $hasBill = array();
        foreach($arrBill as $bill) {
            $filter = array('channel_id' => $this->channel['channel_id'], 'waybill_number' => $bill['logi_no']);
            if (!empty($bill['logi_no']) && ($this->channel['channel_type'] == '360buy' || $objWaybill->dump($filter))) {
                $this->directRet['succ'][] = array(
                    'logi_no' => $bill['logi_no'],
                    'b_id' => $bill['b_id'],
                    'delivery_id' => $delivery['delivery_id'],
                    'delivery_bn' => $delivery['delivery_bn']
                );
            } else {
                $needRequest[] = $bill;
            }
            $hasBill[] = $bill['b_id'];
        }
        if(!empty($needRequest)) {
            $this->needRequestDeliveryId[] = $delivery['delivery_id'];
        }
        $noBill = array_diff($arrBillId, $hasBill);
        if($noBill) {
            foreach($noBill as $val) {
                $this->directRet['fail'][] = array(
                    'b_id' => $val,
                    'msg' => '没有该补打单'
                );
            }
        }
        return $needRequest;
    }

    protected function getDeliveryOrder($deliveryId) {
        $db = kernel::database();
        $deliveryIds = $this->getDeliveryIdBywms($deliveryId);
        $where = is_array($deliveryId) ? 'd.delivery_id in (' . (implode(',', $deliveryIds)) . ')' : 'd.delivery_id = "' . $deliveryIds .'"';
        $field = 'o.order_id, o.order_bn, o.total_amount, o.shop_id, o.createway, o.shop_type,d.delivery_id';
        $sql = 'select '. $field . ' from sdb_ome_delivery_order as d left join sdb_ome_orders as o using(order_id) where ' . $where;
        $result = $db->select($sql);
        return $result;
    }

    //获取两条订单明细
    protected function getOrderItems($order_id) {
        static $orderItems = array();
        if (!$orderItems[$order_id]) {
            $orderItems[$order_id] = app::get('ome')->model('order_items')->getList('*', array('order_id' => $order_id), 0, 2);
        }
        return $orderItems[$order_id];
    }

    //获取两条发货单明细
    public function getDeliveryItems($delivery_id) {
        static $deliveryItems = array();
        if(!$deliveryItems[$delivery_id]) {
            $deliveryItems[$delivery_id] = app::get('wms')->model('delivery_items')->getList('*', array('delivery_id' => $delivery_id),0,2);
        }
        return $deliveryItems[$delivery_id];
    }

    #设置子单的请求的订单号
    public function setChildRqOrdNo($deliveryBn, $billId){
        $deliveryBn = $deliveryBn."cldordno".$billId;
        return $deliveryBn;
    }

    #检查是否是子单的请求的订单号
    public function checkChildRqOrdNo($deliveryBn, &$main_order_no, &$waybill_cid){
        $pos = strpos($deliveryBn,'cldordno');
        if( $pos !== false){
            $main_order_no = substr($deliveryBn,0,$pos);
            $waybill_cid = substr($deliveryBn,$pos+8);
            return true;
        }else{
            return false;
        }
    }

    #验证物流公司是否是该渠道的
    protected function checkLogisticsChannel($logiId) {
        static $channelLogistics = array();
        if(empty($channelLogistics)) {
            $arrLogistics = app::get('ome')->model('dly_corp')->getList('corp_id', array('channel_id'=>$this->channel['channel_id']));
            foreach($arrLogistics as $val) {
                $channelLogistics[] = $val['corp_id'];
            }
        }
        if(in_array($logiId, $channelLogistics)) {
            return true;
        } else {
            return false;
        }
    }

    public function waybillExtendDealParam($arrDelivery, $arrBill) {
        if(!$this->needGetWBExtend) {
            return false;
        }
        $waybill = array();
        $waybillDelivery = array();
        foreach($arrDelivery as $delivery) {
            if(!empty($delivery['logi_no'])) { //需要有运单号
                $waybill[] = $delivery['logi_no'];
                $waybillDelivery[$delivery['logi_no']] = $delivery;
            }
        }
        if(empty($waybill)) {
            return array('sdf' => false);
        }
        $objExtend = app::get("logisticsmanager")->model("waybill_extend");
        $sql = 'SELECT w.waybill_number, e.id FROM sdb_logisticsmanager_waybill w LEFT JOIN sdb_logisticsmanager_waybill_extend e ON (w.id = e.waybill_id) WHERE w.waybill_number in ("'. implode('","', $waybill) .'") AND w.channel_id = "' . $this->channel['channel_id'] . '"';
        $arrExtend = $objExtend->db->select($sql);
        $needExtendDelivery = array();
        foreach($arrExtend as $val) {
            if(empty($val['id']) && $val['waybill_number']) {//没有大头笔
                $needExtendDelivery[] = $waybillDelivery[$val['waybill_number']];
            }
        }
        if(empty($needExtendDelivery)) {
            $billExtend = true;
            if(!empty($arrBill)) {
                $billExtend = $this->dealBillExtend($arrBill, $arrExtend[0]['id']);
            }
            return array('sdf' => false, 'bill_extend_fail' => !$billExtend);
        }
        $shop = app::get('logisticsmanager')->model('channel_extend')->dump(array('channel_id'=>$this->channel['channel_id']),'province,city,area,address_detail,seller_id,default_sender,mobile,tel,zip');
        $sdf = $this->getWaybillExtendSdf($needExtendDelivery, $shop);
        return array('sdf' => $sdf);
    }

    protected function getWaybillExtendSdf($arrDelivery, $shop) {
        return false;
    }

    protected function dealBillExtend($arrBill, $extendId) {
        $billWaybill = array();
        foreach($arrBill as $bill) {
            $billWaybill[] = $bill['logi_no'];
        }
        $objWaybill = app::get("logisticsmanager")->model("waybill");
        $filter = array(
            'waybill_number' => $billWaybill,
            'channel_id' => $this->channel['channel_id']
        );
        $waybill = $objWaybill->getList('id', $filter);
        $waybillId = array();
        foreach($waybill as $val) {
            $waybillId[$val['id']] = 1;
        }
        $objExtend = app::get("logisticsmanager")->model("waybill_extend");
        $extend = $objExtend->getList('waybill_id', array('waybill_id'=>array_keys($waybillId)));
        foreach($extend as $value) {
            if($waybillId[$value['waybill_id']]) {//有大头笔不更新
                unset($waybillId[$value['waybill_id']]);
            }
        }
        $upWaybillId = array_keys($waybillId);
        if($upWaybillId) {
            $extendData = $objExtend->dump(array('id'=>$extendId));
            unset($extendData['id']);
            $insertData = array();
            foreach($upWaybillId as $wbId) {
                $tmp = $extendData;
                $tmp['waybill_id'] = $wbId;
                $insertData[] = $tmp;
            }
            $sql = ome_func::get_insert_sql($objExtend, $insertData);
            return kernel::database()->exec($sql);
        }
        return true;
    }

    public function getDeliveryIdBywms($deliveryId){
        $db = kernel::database();
        $sql = "SELECT w.outer_delivery_bn FROM sdb_wms_delivery as w WHERE w.delivery_id in (".implode(',', $deliveryId).")";
        $delivery_list = $db->select($sql);
        $delivery_bnList = array();
        foreach ($delivery_list as $delivery){
            $delivery_bnList[] = $delivery['outer_delivery_bn'];
        }

        $deliveryArr = $db->select("SELECT d.delivery_id FROM sdb_ome_delivery as d WHERE d.delivery_bn in(".'\''.implode('\',\'',$delivery).'\''.")");
        $deliveryIds = array();
        foreach ($deliveryArr as $deliverys){
            $deliveryIds[] = $deliverys['delivery_id'];
        }
        return $deliveryIds;
    }

    public  function get_corp($corp_id){
        static $corps;
        if (isset($corps[$corp_id])) return $corps[$corp_id];
        $corpModel = app::get('ome')->model('dly_corp');
        $rows = $corpModel->getList('corp_id,type,name,protect,protect_rate',array('corp_id'=>$corp_id));
        foreach ($rows as $row) {
            $corps[$row['corp_id']] = $row;
        }
        return $corps[$corp_id] ? $corps[$corp_id] : array();
    }

    # 扩展发货单
    private function __format_delivery($arrDelivery, $arrBill)
    {
        foreach($arrDelivery as $key => $value) {
            $is_jd_order = false; $totalAmount = 0;
            $deliveryOrder = $this->getDeliveryOrder((array)$value['delivery_id']);
            $arrShopOrderBn = array();
            foreach ($deliveryOrder as $k => $v) {
                if ($v['shop_type'] == '360buy') $is_jd_order = true;
                if ($v['createway'] == 'matrix') $arrShopOrderBn[$v['shop_id']][] = $v['order_bn'];
                $totalAmount += $v['total_amount'];
            }

            // 京东订单推送物流公司，手机号隐藏
            if ($is_jd_order && $this->channel['channel_type']!='taobao') $arrDelivery[$key]['ship_mobile'] = '00000000000';

            $arrDelivery[$key]['total_amount'] = $totalAmount;

            $arrDelivery[$key]['delivery_order'] = $deliveryOrder;
        }

        return $arrDelivery;
    }
}
